@@ -1,5 +1,4 @@
-"""Global configuration state and functions for management -- adapted from sklearn
-"""
+"""Global configuration state and functions for management -- adapted from sklearn"""
 
 import os
 from contextlib import contextmanager as contextmanager
