@@ -194,7 +194,7 @@ class LazyBoostingClassifier(ClassifierMixin):
         self.preprocess = preprocess
         self.n_jobs = n_jobs
 
-    def fit(self, X_train, X_test, y_train, y_test, hist=False,  **kwargs):
+    def fit(self, X_train, X_test, y_train, y_test, hist=False, **kwargs):
         """Fit classifiers to X_train and y_train, predict and score on X_test,
         y_test.
 
@@ -215,7 +215,7 @@ class LazyBoostingClassifier(ClassifierMixin):
             y_test: array-like,
                 Testing vectors, where rows is the number of samples
                 and columns is the number of features.
-            
+
             hist: bool, optional (default=False)
                 When set to True, the model is a GenericBoostingClassifier.
 
@@ -398,7 +398,7 @@ class LazyBoostingClassifier(ClassifierMixin):
                                 )
 
                         else:
-                            if hist is False: 
+                            if hist is False:
                                 fitted_clf = GenericBoostingClassifier(
                                     base_model=model(**kwargs),
                                     verbose=self.verbose,
@@ -495,7 +495,7 @@ class LazyBoostingClassifier(ClassifierMixin):
                         y_test,
                         use_preprocessing=True,
                         preprocessor=preprocessor,
-                        **kwargs
+                        **kwargs,
                     )
                     for name, model in tqdm(self.classifiers)
                 )
@@ -526,16 +526,16 @@ class LazyBoostingClassifier(ClassifierMixin):
                                         random_state=self.random_state
                                     ),
                                     verbose=self.verbose,
-                                    **kwargs
+                                    **kwargs,
                                 )
-                            else: 
+                            else:
                                 fitted_clf = GenericBoostingClassifier(
                                     base_model=model(
                                         random_state=self.random_state
                                     ),
                                     verbose=self.verbose,
                                     hist=True,
-                                    **kwargs
+                                    **kwargs,
                                 )
 
                         else:
@@ -543,14 +543,14 @@ class LazyBoostingClassifier(ClassifierMixin):
                                 fitted_clf = GenericBoostingClassifier(
                                     base_model=model(),
                                     verbose=self.verbose,
-                                    **kwargs
+                                    **kwargs,
                                 )
                             else:
                                 fitted_clf = GenericBoostingClassifier(
                                     base_model=model(),
                                     verbose=self.verbose,
                                     hist=True,
-                                    **kwargs
+                                    **kwargs,
                                 )
 
                         fitted_clf.fit(X_train, y_train)
@@ -622,7 +622,7 @@ class LazyBoostingClassifier(ClassifierMixin):
                         X_test,
                         y_test,
                         use_preprocessing=False,
-                        **kwargs
+                        **kwargs,
                     )
                     for name, model in tqdm(self.classifiers)
                 )
@@ -728,7 +728,7 @@ class LazyBoostingClassifier(ClassifierMixin):
         use_preprocessing=False,
         preprocessor=None,
         hist=False,
-        **kwargs
+        **kwargs,
     ):
         """
         Function to train a single model and return its results.
@@ -764,7 +764,7 @@ class LazyBoostingClassifier(ClassifierMixin):
                         hist=True,
                     )
             else:
-                if hist is False: 
+                if hist is False:
                     fitted_clf = GenericBoostingClassifier(
                         base_model=model(**kwargs),
                         verbose=self.verbose,
