@@ -6,8 +6,8 @@ from .misc import (
     is_factor,
     check_and_install,
     is_multitask_estimator,
-    convert_df_to_numeric, 
-    dict_to_dataframe_series
+    convert_df_to_numeric,
+    dict_to_dataframe_series,
 )
 
 
@@ -20,5 +20,5 @@ __all__ = [
     "check_and_install",
     "is_multitask_estimator",
     "convert_df_to_numeric",
-    "dict_to_dataframe_series"
+    "dict_to_dataframe_series",
 ]
